function [S,I,Q,R,D] = SIRQVModel_244(alpha, beta, gamma, delta, eta, rho, zeta, ICs, Tf)
% This code runs a more complicated SIR model that adds in Q (a quarantined
% population) and D (a deceased population). The V component adds
% vaccination into the picture, where members are moved from S to R
% directly. The system of differential equations used here is
%   S' = -alpha*S*I - zeta*S
%   I' = alpha*S*I - (beta+gamma+delta)I
%   Q' = beta*I - (eta + rho)Q
%   R' = gamma*I + eta*Q+zeta*S
%   D' = delta*I + rho*Q
%
% The solution is computed using the RungeKutta method, with the helper
% method rungeKuttaSystemMethod. The system is solved from t=0 to t=Tf,
% with initial conditions ICs given as a 5 component vector.

DE = @(t, x) [-alpha.*x(1).*x(2) - zeta.*x(1); alpha.*x(1).*x(2) - (beta+gamma+delta).*x(2); beta*x(2) - (eta + rho)*x(3); gamma*x(2) + eta*x(3)+zeta.*x(1); delta*x(2) + rho*x(3)];

[~, x] = rungeKuttaSystemMethod(DE, 0, Tf, 1, ICs);

S = x(1, :);
I = x(2, :);
Q = x(3, :);
R = x(4, :);
D = x(5, :);
end